govdelivery
===========

A quite incomplete API client for govdelivery

Currently, you can subscribe a user, manage their topic and category subscriptions, and get the list of available topics.

The govdelivery API is described here: http://knowledge.govdelivery.com/display/API/API+Methods


## Dependencies

This app has not been tested with Python3

## Installation

`pip install govdelivery`

----

## Open source licensing info
1. [TERMS](TERMS.md)
2. [LICENSE](LICENSE)
3. [CFPB Source Code Policy](https://github.com/cfpb/source-code-policy/)
